[Erp5-report] r11128 - /erp5/trunk/products/ERP5Type/CachePlugins/DistributedRamCache.py

nobody at svn.erp5.org nobody at svn.erp5.org
Mon Nov 6 16:27:07 CET 2006


Author: ivan
Date: Mon Nov  6 16:27:00 2006
New Revision: 11128

URL: http://svn.erp5.org?rev=11128&view=rev
Log:
memcached server doesn't support namespaces (cache scopes). When explicitly called clearCacheForScope() we have no choice but clear whole cache.

Modified:
    erp5/trunk/products/ERP5Type/CachePlugins/DistributedRamCache.py

Modified: erp5/trunk/products/ERP5Type/CachePlugins/DistributedRamCache.py
URL: http://svn.erp5.org/erp5/trunk/products/ERP5Type/CachePlugins/DistributedRamCache.py?rev=11128&r1=11127&r2=11128&view=diff
==============================================================================
--- erp5/trunk/products/ERP5Type/CachePlugins/DistributedRamCache.py (original)
+++ erp5/trunk/products/ERP5Type/CachePlugins/DistributedRamCache.py Mon Nov  6 16:27:00 2006
@@ -141,5 +141,7 @@
     cache_storage.flush_all()
     
   def clearCacheForScope(self, scope):
-    ## memcached doesn't support namespaces (cache scopes) neither getting cached key list 
-    pass       
+    ## memcached doesn't support namespaces (cache scopes) neither getting cached key list.
+    ## Becasue we've explicitly called this function instead of clearing specific cache 
+    ## scope we have no choice but clear whole cache.
+    self.clearCache()       




More information about the Erp5-report mailing list